%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Trade Reforms and Labor Market Adjustments - Codes - v 2011/11/26
% Head-to-head with Lewis-like unemployment extending Helpman-Itskhoki
% Solve for steady state allocations
% + MEDIUM RUN ALLOCATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% SETTING GVARS + INITIAL & FINAL TARIFFS
setgvars;

tau_ini         = 1.45;
tau_fin         = 1.38;

%index
ini             = 1;
fin             = 2;
N               = 2;

% adjusting the gvars
taus(ini)       = tau_ini;
taus(fin)       = tau_fin;

gs              = [gvars ; gvars];
gs(ini).tau     = taus(ini);
gs(fin).tau     = taus(fin);



%% COMPUTE LONG RUN EQUILIBRIA FOR EACH TARIFF

Qs              = zeros(N,1);
cH_maxs         = zeros(N,1);

parfor i   = 1:N   
   [Qs(i), cH_maxs(i)]  = h2hlewis(gs(i));   
   fprintf('Done with loop iteration %g \n', i);
end

%% STORING POPULATION BY UNIT COSTS AND BY TYPE

Nc              = 500;

cbarH           = gvars.gamma + gvars.b;
cbarM           = cbarH*gvars.alpha;

cvecH           = linspace(0,cbarH,Nc);
cvecM           = linspace(0,cbarH*gvars.alpha,Nc*gvars.alpha);
        
popMvec_ini     = popM(cvecM,Qs(ini),Qs(ini),gs(ini));

popHfcn_ini     = @(c) popH(c,Qs(ini),Qs(ini),cH_maxs(ini),gs(ini));
popHvec_ini     = arrayfun(popHfcn_ini,cvecH);


%% COMPUTING THE TRANSITION INCOME

[Q_trans, cH_max_trans]  = h2hlewis_trans(Qs(fin),popMvec_ini,popHvec_ini,...
                                            cvecM,cvecH,gs(fin));

