%% PLOT - FIGURE 1 - IMP. COMP. versus UNEMPL

%% parameters
alpha   = gvars.alpha;
b       = gvars.b;
gamma   = gvars.gamma;
delta   = gvars.delta;


cmax    = gamma + b;
Npts    = 500;

cvecM   = linspace(0,cmax*alpha,Npts);
cvecH   = linspace(0,cmax,Npts);

h       = 1;
f       = 1;


%% lagrangians

psiHfun          = @(x,y) ...
    psiH_trans(x,y,Qs_trans(med),Qs_trans(med),cH_maxs_trans(med),...
                Qs_trans(ini),Qs_trans(ini),cH_maxs_trans(ini),...
                gs_trans(ini),gs_trans(med));
            
psiMfun          = @(x)   ...
    psiM_trans(x,Qs_trans(med),Qs_trans(med),Qs_trans(ini),Qs_trans(ini),...
                gs_trans(ini),gs_trans(med));
            
            
%% employment

empMvec = zeros(N,Npts);
empHvec = zeros(N,Npts);

for i = [ini,fin]
    empMvec(i,:) = totalM(@sizeM,cvecM,Qs_trans(i),Qs_trans(i),h,f,gs_trans(i));
    empHvec(i,:) = expected_totalH(@sizeH,cvecH,...
                    Qs_trans(i),Qs_trans(i),cH_maxs_trans(i),h,f,gs_trans(i));
end
            
empMvec(med,:) = totalM_trans(@sizeM_trans,cvecM,...
    Qs_trans(med),Qs_trans(med),psiMfun(cvecM),h,f,gs_trans(med));

empHvec(med,:) = expected_totalH_trans(@sizeH_trans,cvecH,...
    Qs_trans(med),Qs_trans(med),cH_maxs_trans(med),psiHfun,h,f,gs_trans(med));

%% economy wide unemployment
nonemplvec = zeros(N,1);

for i = [ini,fin]
    nonemplvec(i) = nonempl(Qs_trans(i),cH_maxs_trans(i),gs_trans(i));
end
            
nonemplvec(med) = nonempl_trans(Qs_trans(med),cH_maxs_trans(med),...
    Qs_trans(ini),cH_maxs_trans(ini),gs_trans(ini),gs_trans(med));

%% economy wide taa
sumtaavec = zeros(N,1);

for i = [ini,fin]
    sumtaavec(i) = sumtaaH(Qs_trans(i),cH_maxs_trans(i),gs_trans(i));
end
            
sumtaavec(med) = sumtaaH_trans(Qs_trans(med),cH_maxs_trans(med),...
    Qs_trans(ini),cH_maxs_trans(ini),h,f,gs_trans(ini),gs_trans(med));


%% population

popMvec = zeros(N,Npts);
popHvec = zeros(N,Npts);

for i = [ini,fin]
    popMvec(i,:) = totalM(@payrollM,cvecM,Qs_trans(i),Qs_trans(i),h,f,...
                        gs_trans(i));
    popHvec(i,:) = expected_totalH(@payrollH,cvecH,...
                    Qs_trans(i),Qs_trans(i),cH_maxs_trans(i),h,f,...
                        gs_trans(i));
end
            
popMvec(med,:) = popMvec(ini,:);

popHvec(med,:) = popHvec(ini,:);


%% H-to-M switch adjusted employment by labor market

empswitchMvec = zeros(N,Npts);
empswitchHvec = zeros(N,Npts);

for i = [ini,fin]
    empswitchMvec(i,:) = empMvec(i,:);
    empswitchHvec(i,:) = empHvec(i,:);
end
            
empswitchMvec(med,:) = empMvec(med,:);
empswitchHvec(med,:) = empHvec(med,:);

if cH_maxs_trans(ini) >= cH_maxs_trans(med)
    
    sameoldH  = cvecH <= cH_maxs_trans(med);
    sameoldM  = cvecH >  cH_maxs_trans(ini);
    newH2Ms   = cvecH <= cH_maxs_trans(ini) & cvecH >  cH_maxs_trans(med);

    empswitchHvec(med,:) = (1-delta)*empHvec(med,:) + ...
        delta*(sameoldH | sameoldM).*empHvec(med,:) + ...
        delta*(newH2Ms).*interp1(cvecM, empMvec(med,:), alpha*cvecH);

else
    fprintf('Expansion of H-sector - This code is not valid - ADJUST \n')
end

%% taa

taaMvec = zeros(N,Npts);
taaHvec = zeros(N,Npts);

for i = [ini,fin]
    taaMvec(i,:) = 0;
    taaHvec(i,:) = taaH(cvecH,...
                    Qs_trans(i),cH_maxs_trans(i),gs_trans(i));
end

taaMvec(med,:) = 0;
taa_lbvec        = cvecH/gs_trans(ini).tau;
taa_ubvec       = cvecH/gs_trans(med).tau;
 taaHvec(med,:) = expected_totalpartH(taa_lbvec,taa_ubvec,@sizeH,cvecH,...
                    Qs_trans(ini),Qs_trans(ini),cH_maxs_trans(ini),h,f,gs_trans(ini));


%% taa_wap

taawapMvec = taaMvec ./ popMvec;

taawapHvec = taaHvec ./ popHvec;


%% unempl (no work)


nwkMvec = 1 - empMvec ./ popMvec;
nwkHvec = 1 - empHvec ./ popHvec;

nwkswitchMvec = 1 - empswitchMvec ./ popMvec;
nwkswitchHvec = 1 - empswitchHvec ./ popHvec;

%% the bad taa

% taa_wap as interim change in imp. comp
dtaawapH = taawapHvec(med,:) - taawapHvec(ini,:);

% interim change in unemp
dnwkswitchH = nwkswitchHvec(med,:) - nwkHvec(ini,:);

% Suppose the US TAA only picks up labor market that are badly affected
cutoff    = +0.005;
UStaawapH = ( dnwkswitchH >= cutoff).*dtaawapH;

%% transfers viewed thru avg earning across labor markets in the transition

avgW_all = avgearnings_trans(Qs_trans(med),cH_maxs_trans(med),...
                Qs_trans(ini),cH_maxs_trans(ini),psiHfun,psiMfun,...
                gs_trans(ini),gs_trans(med));
            
avgWMvec = avgearningsM_trans(cvecM,Qs_trans(med),Qs_trans(ini),...
                psiMfun,gs_trans(ini),gs_trans(med));            

avgWHvec = avgearningsH_trans(cvecH,Qs_trans(med),cH_maxs_trans(med),...
                Qs_trans(ini),cH_maxs_trans(ini),psiHfun,psiMfun,...
                gs_trans(ini),gs_trans(med));
            
            
%% state-wide stats
% Nus     = 50;
% % generate a skewed distribution of "states"
% curvus  = 2;
% limus   = linspace(0,1,Nus+1).^(1/curvus);
% 
% dtaawap_us  = zeros(Nus,1);
% dunempl_us  = zeros(Nus,1);
% totpop_us   = zeros(Nus,1);
% tottaa_us   = zeros(Nus,1);
% 
% for j =  1:Nus
%     lb              = cmax*limus(j);
%     ub              = cmax*limus(j+1);
%     totpop_us(j)    = 
%     
% end

%% ECONOMY WIDE STATS

fprintf('***** Unemployment & TAA per 000s wap *********** \n')
disp([(1:N)', taus_trans, nonemplvec , 1000*sumtaavec])

%% SOME REGRESSIONS
const   = ones(size(cvecH));


try
idx     = find(UStaawapH > 0);
y       = dnwkswitchH(idx)';
X       = [const(idx)'  UStaawapH(idx)'];
beta1   = regress(y,X);
catch ME1
    beta1 = zeros(2,1);
end

idx     = find(dtaawapH >= -Inf);
y       = dnwkswitchH(idx)';
X       = [const(idx)'  dtaawapH(idx)'];
beta2   = regress(y,X);

fprintf('Regression coeff. on \n biased TAA  vs.  raw TAA \n')
disp([beta1, beta2])


%% PLOTS

plotgraphs = 1;

if plotgraphs == 1

set(0,'DefaultFigureWindowStyle','docked')


% % plotting size(med)/size(ini) by type and productivity
% figure; 
% plot(cvecH,empHvec(med,:) ./ empHvec(ini,:) , ...
%     cvecH,empHvec(fin,:) ./ empHvec(ini,:) )
% title({'Employment to Initial Employment';'transition vs final'; ...
%     [num2str(tau_ini),' to ', num2str(tau_fin)]})


% plotting size/pop by type and productivity
figure; 
plot(cvecH/cmax,empHvec(ini,:) ./ popHvec(ini,:) , ...
    cvecH/cmax,empHvec(med,:) ./ popHvec(ini,:) , 'bo',...
    cvecH/cmax,empHvec(fin,:) ./ popHvec(ini,:) ,...
    cvecH/cmax,ones(size(cvecH)))
grid on
title({'Employment to Initial Population';'transition vs final'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})

figure; 
plot(cvecH/cmax,empHvec(ini,:) ./ popHvec(ini,:) , ...
    cvecH/cmax,empHvec(fin,:) ./ popHvec(fin,:) )
grid on
title({'LR Employment to Population';'initial vs final'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})

% plotting switch adjust. empl
figure; 
plot(cvecH/cmax,empHvec(med,:) ./ popHvec(ini,:) , 'bo',...
    cvecH/cmax,empswitchHvec(med,:) ./ popHvec(ini,:),'rs' )
grid on
title({'Employment to Initial Population';'with switch vs no switch'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})

% reallocation bounds
figure; 
plot(taawapHvec(med,:) - taawapHvec(ini,:), ...
    nwkswitchHvec(med,:) - nwkHvec(ini,:), 'bo')
grid on
title({'Foreign Competition and Unemployment Changes';...
    ' (\Delta TAA vs \Delta Unempl.)'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})

% reallocation bounds
% figure; 
% plot(UStaawapH, dnwkswitchH, 'bo')
% title({'Foreign Competition and Unemployment Changes';...
%     ' (\Delta TAA vs \Delta Unempl.)'; ...
%     [num2str(tau_ini),' to ', num2str(tau_fin)]})

figure; 
plot(cvecH/cmax, taawapHvec(med,:) - taawapHvec(ini,:), 'bo',...
    cvecH/cmax, nwkswitchHvec(med,:) - nwkHvec(ini,:),'ks')
grid on
title({'Foreign Competition and Unemployment Change';'by labor market'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})


% reallocations bounds + H-to-M switch
figure; 
plot(taawapHvec(med,:) - taawapHvec(ini,:), ...
    nwkswitchHvec(med,:) - nwkHvec(ini,:), 'rs',... 
    taawapHvec(med,:) - taawapHvec(ini,:), ...
    nwkHvec(med,:) - nwkHvec(ini,:), 'bo')
grid on
title({'Technology switch effect';...
    'Foreign Competition and Unemployment Changes';...
    ' (\Delta TAA vs \Delta Unempl.)'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})


% transfers measures thru avg. earnings
figure; 
%plot(cvecH/cmax, avgWHvec, 'bo',...
 %   cvecH/cmax, avgW_all*ones(size(cvecH)))
plot(taawapHvec(med,:) - taawapHvec(ini,:),...
    avgWHvec/avgW_all, 'bo')
grid on
title({'Average Earnings per w.a.p.';  ...
    ' (\Delta TAA vs Demeaned Earnings)'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})


% figure; 
% plot(taawapHvec(med,:) - taawapHvec(ini,:), ...
%     ( nwkswitchHvec(med,:) - nwkHvec(ini,:) ) - ...
%     ( nwkHvec(med,:) - nwkHvec(ini,:) ), 'bo')
% title({'Technology switch effect';'Difference in Unemployment Changes';...
%     ' (\Delta TAA vs \Delta \Delta Unempl.)'; ...
%     [num2str(tau_ini),' to ', num2str(tau_fin)]})

% free reallocations
figure; 
plot(taawapHvec(fin,:) - taawapHvec(ini,:), ...
    nwkHvec(fin,:) - nwkHvec(ini,:),'bo')
grid on
title({'LR Foreign Competition and Unemployment Changes';...
    'initial to final'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})

figure; 
plot(cvecH/cmax, taawapHvec(fin,:) - taawapHvec(ini,:),'bo',...
    cvecH/cmax, nwkHvec(fin,:) - nwkHvec(ini,:),'ks')
grid on
title({'LR Foreign Competition and Unemployment Changes'; ...
    ' (\Delta TAA vs \Delta Unempl. from ini to final)'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})

% non head-to-head
% figure; 
% plot(cvecM, nwkMvec(med,:) - nwkMvec(ini,:),'bo', ...
%     cvecM, nwkMvec(fin,:) - nwkMvec(ini,:),'ks')
% title({'LR/MR Unemployment Changes in the M sector';...
%     ' by labor market'; ...
%     [num2str(tau_ini),' to ', num2str(tau_fin)]})

% population dynamics
figure; 
plot(cvecM/cmax, popMvec(fin,:) ./ popMvec(ini,:),'bo', ...
    cvecH/cmax, popHvec(fin,:) ./ popHvec(ini,:),'ks')
grid on
title({'LR Population adjustments';' by labor market'; ...
    [num2str(tau_ini),' to ', num2str(tau_fin)]})

set(0,'DefaultFigureWindowStyle','normal')
end



